@@ -301,7 +301,6 @@ class Publish(object):
         """
         Serialize publish in YAML
         """
-        name = self.name.replace('/', '-')
         timestamp = time.strftime("%Y%m%d%H%M%S")
 
         yaml_dict = {}
@@ -320,6 +319,7 @@ class Publish(object):
             yaml_dict["components"].append({'component': component, 'snapshot': snapshot['Name'],
                                             'description': snapshot['Description'], 'packages': package_dict})
 
+        name = self.name.replace('/', '-')
         lg.info("Saving publish %s in %s" % (name, save_path))
         with open(save_path, 'w') as save_file:
             yaml.dump(yaml_dict, save_file, default_flow_style=False)
@@ -598,15 +598,21 @@ class Publish(object):
                 packages = self.client.do_get('/snapshots/%s/packages' % snapshot)
                 package_refs.extend(packages)
 
-            self.client.do_post(
-                '/snapshots',
-                data={
-                    'Name': snapshot_name,
-                    'SourceSnapshots': snapshots,
-                    'Description': "Merged from sources: %s" % ', '.join("'%s'" % snap for snap in snapshots),
-                    'PackageRefs': package_refs,
-                }
-            )
+            try:
+                self.client.do_post(
+                    '/snapshots',
+                    data={
+                        'Name': snapshot_name,
+                        'SourceSnapshots': snapshots,
+                        'Description': "Merged from sources: %s" % ', '.join("'%s'" % snap for snap in snapshots),
+                        'PackageRefs': package_refs,
+                    }
+                )
+            except AptlyException as e:
+                if e.res.status_code == 400:
+                    lg.warning("Error creating snapshot %s, assuming it already exists" % snapshot_name)
+                else:
+                    raise
 
             self.publish_snapshots.append({
                 'Component': component,
